<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="xml" encoding="utf-8" indent="yes"
    doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"
    doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd" />

  <xsl:param name="coll" />

  <xsl:template match="/">
    <xsl:apply-templates select="patches" />
  </xsl:template>

  <xsl:template match="patches">
    <html>
      <head>
	<title>
	  <xsl:text>A couple of weird FreeBSD patchsets</xsl:text>
	  <xsl:if test="$coll">
	    <xsl:value-of select="concat(' - ', $coll)" />
	  </xsl:if>
	</title>
      </head>
      <body>
	<h1>
	  <xsl:text>A couple of weird FreeBSD patchsets</xsl:text>
	  <xsl:if test="$coll">
	    <xsl:value-of select="concat(' - ', $coll)" />
	  </xsl:if>
	</h1>

	<xsl:if test="string-length($coll) > 0">
	  <p><a href="patches.html">Main</a></p>

	  <xsl:call-template name="patchset">
	    <xsl:with-param name="cname">
	      <xsl:value-of select="$coll" />
	    </xsl:with-param>
	  </xsl:call-template>
	</xsl:if>

	<xsl:if test="string-length($coll) = 0">
	  <ul>
	    <li>
	      <a href="#ports">ports</a>
	      (also in a <a href="patches-ports.html">separate file</a>)
	    </li>
	    <li>
	      <a href="#src4">src4</a>
	      (also in a <a href="patches-src4.html">separate file</a>)
	    </li>
	    <li>
	      <a href="#src5">src5</a>
	      (also a <a href="patches-src5.html">separate file</a>)
	    </li>
	    <li>
	      <a href="bsd-patches.tar.gz">All patchsets in one</a>
	      (*almost* guaranteed to be up-to-date ;)
	    </li>
	    <li>
	      <a href="news.html">What's new</a> (also as a
	      <a href="news.rss">RSS newsfeed</a>)
	    </li>
	  </ul>

	  <xsl:call-template name="patchset">
	    <xsl:with-param name="cname">ports</xsl:with-param>
	  </xsl:call-template>
  
	  <xsl:call-template name="patchset">
	    <xsl:with-param name="cname">src4</xsl:with-param>
	  </xsl:call-template>
  
	  <xsl:call-template name="patchset">
	    <xsl:with-param name="cname">src5</xsl:with-param>
	  </xsl:call-template>
	</xsl:if>

	<br />
	<hr noshade="noshade" />
	<br />

	<p>
	  <a href="http://validator.w3.org/check/referer"><img
	    src="../images/valid-xhtml10.png" alt="Valid XHTML 1.0!"
	    height="31" width="88" border="0" /></a>

	  <a href="http://xmlsoft.org/XSLT/"><img
	    src="../images/Libxslt-Logo-180x168.gif" alt="Powered by Libxslt"
	    border="0" /></a>
	</p>
	
	<p>
	  Generated from:
	  <br />
	  <xsl:value-of select="vcs-id" />
	  <br />
	  <xsl:text>$Ringlet: bsd-patches/patches.xsl,v 1.8 2004/01/08 08:33:58 roam Exp $</xsl:text>
	</p>
      </body>
    </html>
  </xsl:template>

  <xsl:template name="patchset">
    <xsl:param name="cname" />
    
    <xsl:element name="a">
      <xsl:attribute name="name">
	<xsl:value-of select="$cname" />
      </xsl:attribute>
    </xsl:element>

    <h2>
      <xsl:text>Patchset: </xsl:text>
      <xsl:element name="a">
	<xsl:attribute name="href">
	  <xsl:value-of select="concat('patches-', $cname, '.html')" />
	</xsl:attribute>
	<xsl:value-of select="$cname" />
      </xsl:element>
    </h2>
    <table border="1" cellspacing="2" cellpadding="2">
      <tr>
	<td><strong>Patch name</strong></td>
	<td><strong>Collection(s)</strong></td>
	<td><strong>Description</strong></td>
      </tr>
      
      <xsl:for-each select="patch">
	<xsl:if test="avail/@coll=$cname">
	  <xsl:call-template name="patch">
	    <xsl:with-param name="coll">
	      <xsl:value-of select="$cname" />
	    </xsl:with-param>
	  </xsl:call-template>
	</xsl:if>
      </xsl:for-each>
    </table>
  </xsl:template>

  <xsl:template name="patch">
    <xsl:param name="coll" />

    <tr>
      <td>
	<xsl:element name="a">
	  <xsl:attribute name="href">
	    <xsl:value-of select="concat($coll, '/', @name)" />
	  </xsl:attribute>
	  <xsl:value-of select="@name" />
	</xsl:element>
      </td>

      <td>
	<xsl:for-each select="avail">
	  <xsl:text> </xsl:text>
	  <xsl:element name="a">
	    <xsl:attribute name="href">
	      <xsl:value-of select="concat(@coll, '/', ../@name)" />
	    </xsl:attribute>
	    <xsl:value-of select="@coll" />
	  </xsl:element>
	</xsl:for-each>
      </td>
      
      <xsl:choose>
	<xsl:when test="description and string-length(description) > 0">
	  <td><xsl:apply-templates select="description" /></td>
	</xsl:when>
	<xsl:otherwise>
	  <td>(no description available)</td>
	</xsl:otherwise>
      </xsl:choose>
    </tr>
  </xsl:template>
</xsl:stylesheet>

